## Aliyun ROS CLOUDSTORAGEGATEWAY Construct Library

This module is part of the AliCloud ROS Cloud Development Kit (ROS CDK) project.

```python
import * as CLOUDSTORAGEGATEWAY from '@alicloud/ros-cdk-cloudstoragegateway';
```
